'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var core = require('@weamd/core');
var utils = require('@weamd/utils');
var prosemirrorKeymap = require('prosemirror-keymap');
var prosemirrorState = require('prosemirror-state');

/* Copyright 2021, Milkdown by Mirone. */
const updateIndent = (tr, options) => {
    const { doc, selection } = tr;
    if (!doc || !selection)
        return tr;
    if (!(selection instanceof prosemirrorState.TextSelection || selection instanceof prosemirrorState.AllSelection)) {
        return tr;
    }
    const { to } = selection;
    const text = options.type === 'space' ? Array(options.size).fill(' ').join('') : '\t';
    return tr.insertText(text, to);
};
const applyStyle = (options, utils) => {
    if (options.type === 'tab') {
        utils.getStyle(({ injectGlobal }) => injectGlobal `
                .milkdown {
                    tab-size: ${options.size};
                }
            `);
    }
};
const Indent = core.createCmdKey('Indent');
const indentPlugin = utils.createPlugin((utils, options) => ({
    prosePlugins: () => {
        const config = Object.assign({ type: 'tab', size: 4 }, (options !== null && options !== void 0 ? options : {}));
        utils.themeManager.onFlush(() => {
            applyStyle(config, utils);
        });
        const plugin = prosemirrorKeymap.keymap({
            Tab: (state, dispatch) => {
                const { tr } = state;
                const _tr = updateIndent(tr, config);
                if (_tr.docChanged) {
                    dispatch === null || dispatch === void 0 ? void 0 : dispatch(_tr);
                    return true;
                }
                return false;
            },
        });
        return [plugin];
    },
}));
const indent = utils.AtomList.create([indentPlugin()]);

exports.Indent = Indent;
exports.indent = indent;
exports.indentPlugin = indentPlugin;
//# sourceMappingURL=index.cjs.map
