import { createCmdKey } from '@weamd/core';
import { createPlugin, AtomList } from '@weamd/utils';
import { keymap } from 'prosemirror-keymap';
import { TextSelection, AllSelection } from 'prosemirror-state';

/* Copyright 2021, Milkdown by Mirone. */
const updateIndent = (tr, options) => {
    const { doc, selection } = tr;
    if (!doc || !selection)
        return tr;
    if (!(selection instanceof TextSelection || selection instanceof AllSelection)) {
        return tr;
    }
    const { to } = selection;
    const text = options.type === 'space' ? Array(options.size).fill(' ').join('') : '\t';
    return tr.insertText(text, to);
};
const applyStyle = (options, utils) => {
    if (options.type === 'tab') {
        utils.getStyle(({ injectGlobal }) => injectGlobal `
                .milkdown {
                    tab-size: ${options.size};
                }
            `);
    }
};
const Indent = createCmdKey('Indent');
const indentPlugin = createPlugin((utils, options) => ({
    prosePlugins: () => {
        const config = Object.assign({ type: 'tab', size: 4 }, (options !== null && options !== void 0 ? options : {}));
        utils.themeManager.onFlush(() => {
            applyStyle(config, utils);
        });
        const plugin = keymap({
            Tab: (state, dispatch) => {
                const { tr } = state;
                const _tr = updateIndent(tr, config);
                if (_tr.docChanged) {
                    dispatch === null || dispatch === void 0 ? void 0 : dispatch(_tr);
                    return true;
                }
                return false;
            },
        });
        return [plugin];
    },
}));
const indent = AtomList.create([indentPlugin()]);

export { Indent, indent, indentPlugin };
//# sourceMappingURL=index.mjs.map
